api.cases.v2 package — Argus-Toolbelt 1.0 documentation

# api.cases.v2 package

## Submodules

## api.cases.v2.case module

Autogenerated API

`api.cases.v2.case.` `acknowledge_workflow`(caseID: int, workflow: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Acknowledge workflow on case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID workflow (str) – Workflow to acknowledge
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 756, “limit”: 932, “responseCode”: 200, “count”: 1000, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Later team serious investment.”, “messageTemplate”: “Nation grow know set serve coach.”, “field”: “Pull store voice positive gas current allow.”, “parameter”: {}, “timestamp”: 569878334}], “currentPage”: 864, “size”: 532}

`api.cases.v2.case.` `add_attachment`(caseID: int, name: str = None, mimeType: str = None, data: str = None, encryptedZip: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add new attachment (PUBLIC) Upload new attachment as JSON object with base64-encoded data

  Return type: | `dict`

`api.cases.v2.case.` `add_case_link`(caseID: int, linkToCaseID: int, type: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add link to case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – ID of case to link from linkToCaseID (int) – ID of case to link to type (str) – Type of link to add
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 319, “limit”: 405, “responseCode”: 200, “count”: 706, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Model meet fish sea detail time.”, “messageTemplate”: “Across east work blood.”, “field”: “Within course including subject decide defense.”, “parameter”: {}, “timestamp”: 288735196}], “currentPage”: 22, “size”: 346}

`api.cases.v2.case.` `add_case_tag`(caseID: int, tags: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add tag to case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID tags (list) – Add multiple tags as key/value strings or JSON objects
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 115, “limit”: 638, “responseCode”: 200, “count”: 939, “data”: [{“id”: “Suggest car hard similar enjoy if.”, “addedTimestamp”: 689100448, “addedByUser”: {“id”: 745, “customerID”: 783, “userName”: “brandonberg”, “name”: “Kimberly Jones”}, “key”: “Offer prove need group.”, “value”: “Into field building magazine let listen story black.”, “flags”: [“DELETED”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “National mouth item black.”, “messageTemplate”: “Ask song during responsibility.”, “field”: “Sell toward sea mother local stop day everything.”, “parameter”: {}, “timestamp”: 670794832}], “currentPage”: 513, “size”: 551}

`api.cases.v2.case.` `add_case_watcher`(caseID: int, subjectID: int = None, destination: str = None, type: str = 'email', verbose: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add watcher to case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID subjectID (int) – Subject to add watcher for destination (str) – Contact information to add as watcher (email address or phone number). If subject is specified, this is ignored. type (str) – Type of watcher to add (default email) verbose (bool) – If set, explicitly set verbosity for watcher (will override default settings on subject)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 982, “limit”: 196, “responseCode”: 200, “count”: 742, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Hair ability two during threat week.”, “messageTemplate”: “Time late Republican respond together.”, “field”: “Few decide system cold radio hard.”, “parameter”: {}, “timestamp”: 1243000758}], “currentPage”: 788, “size”: 168}

`api.cases.v2.case.` `add_comment`(caseID: int, asReplyTo: str = None, comment: str = None, originEmailAddress: str = None, internal: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Submit new comment to case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID asReplyTo (str) – Optional ID of comment to reply to. comment (str) – Comment to add. Html is allowed, will be sanitized. originEmailAddress (str) – If comment is added from an email, specify origin email address here => format:email internal (bool) – If true, mark comment as internal, only visible to service techs. Default is false.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 852, “limit”: 889, “responseCode”: 200, “count”: 523, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Wide class similar.”, “messageTemplate”: “Service main tell entire threat bar offer.”, “field”: “Letter claim forget direction good way.”, “parameter”: {}, “timestamp”: 731774646}], “currentPage”: 116, “size”: 898}

`api.cases.v2.case.` `advanced_case_search`(limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, caseID: list = None, type: list = None, service: list = None, category: list = None, status: list = None, priority: list = None, startTimestamp: int = None, endTimestamp: int = None, assetID: list = None, tag: list = None, workflow: list = None, field: list = None, keywords: list = None, timeFieldStrategy: list = None, timeMatchStrategy: str = None, keywordFieldStrategy: list = None, keywordMatchStrategy: str = None, userID: list = None, userFieldStrategy: list = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', userAssigned: bool = 'False', techAssigned: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns cases matching the defined CaseSearchCriteria (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. caseID (list) – Restrict search to specific cases (by ID). type (list) – Restrict search to entries of one of these types. service (list) – Restrict search to entries of one of these services (by service shortname or ID). category (list) – Restrict search to entries of one of these categories (by category shortname or ID). status (list) – Restrict search to entries of one of these statuses. priority (list) – Restrict search to entries with given priorties startTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (start timestamp). endTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (end timestamp). assetID (list) – Restrict search to cases associated with specified assets (hosts, services or processes) tag (list) – Restrict search to entries matching the given tag criteria. workflow (list) – Restrict search to entries matching the given workflow criteria. field (list) – Restrict search to entries matching the given field criteria. keywords (list) – Search for keywords. timeFieldStrategy (list) – Defines which timestamps will be included in the search (default lastUpdatedTimestamp). timeMatchStrategy (str) – Defines how strict to match against different timestamps (all/any) using start and end timestamp (default any) keywordFieldStrategy (list) – Defines which fields will be searched by keywords (default all supported fields). keywordMatchStrategy (str) – Defines the MatchStrategy for keywords (default match all keywords). userID (list) – Restrict search to cases associated with these users. userFieldStrategy (list) – Defines which user fields will be searched (default match all user fields). sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). userAssigned (bool) – If set, limit search to cases where assignedUser field is set/unset techAssigned (bool) – If set, limit search to cases where assignedTech field is set/unset
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 635, “limit”: 383, “responseCode”: 200, “count”: 148, “data”: [{“id”: 285, “initialStatus”: “pendingClose”, “status”: “closed”, “initialPriority”: “high”, “priority”: “critical”, “subject”: “Whatever tree learn.”, “description”: “Happen site central full team Congress.”, “customerReference”: “Through must kitchen activity coach.”, “accessMode”: “writeRestricted”, “reporter”: {“id”: 151, “customerID”: 472, “userName”: “elizabeth15”, “name”: “Jasmine Gardner”}, “assignedUser”: {“id”: 31, “customerID”: 31, “userName”: “aaronmartinez”, “name”: “Heather Williams”}, “assignedTech”: {“id”: 854, “customerID”: 638, “userName”: “michael56”, “name”: “Megan Baker”}, “createdTimestamp”: 728519441, “createdByUser”: {“id”: 549, “customerID”: 286, “userName”: “lewisdorothy”, “name”: “Henry Smith”}, “lastUpdatedTimestamp”: 661456873, “lastUpdatedByUser”: {“id”: 832, “customerID”: 214, “userName”: “marshallmichael”, “name”: “Sharon Diaz”}, “closedTimestamp”: 242533426, “closedByUser”: {“id”: 843, “customerID”: 427, “userName”: “martintodd”, “name”: “Casey Carter”}, “publishedTimestamp”: 12841414, “publishedByUser”: {“id”: 879, “customerID”: 907, “userName”: “whall”, “name”: “Heather Bryant”}, “flags”: [“MAIL_UPDATE”], “properties”: {“additionalProperties”: “New role hour central from admit.”}}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Machine station drug let culture huge.”, “messageTemplate”: “Of attention special carry.”, “field”: “Opportunity say peace build break nature player.”, “parameter”: {}, “timestamp”: 1350982788}], “currentPage”: 922, “size”: 701}

`api.cases.v2.case.` `change_access_settings`(caseID: int, accessMode: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Change general access settings (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID accessMode (str) – If set, this will alter the access mode of the case.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 641, “limit”: 735, “responseCode”: 200, “count”: 878, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Rate minute thousand production.”, “messageTemplate”: “Be up specific hope year moment quite.”, “field”: “Large fly heart civil.”, “parameter”: {}, “timestamp”: 511178376}], “currentPage”: 606, “size”: 577}

`api.cases.v2.case.` `close_case`(caseID: int, comment: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Close an open case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID comment (str) – Closing comment to add to case. May use HTML, will be sanitized.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 57, “limit”: 237, “responseCode”: 200, “count”: 285, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Dinner great couple box.”, “messageTemplate”: “Degree medical cell.”, “field”: “Into its example.”, “parameter”: {}, “timestamp”: 951111860}], “currentPage”: 392, “size”: 92}

`api.cases.v2.case.` `create_case`(service: str = None, category: str = None, type: str = None, status: str = None, watchers: list = None, fields: list = None, subject: str = None, description: str = None, customerReference: str = None, aclMembers: list = None, originEmailAddress: str = None, publish: bool = 'True', defaultWatchers: bool = 'True', priority: str = 'medium', accessMode: str = 'roleBased', customerID: int = 0, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Create a new case defined by CaseCreateRequest (PUBLIC)

  Return type: | `dict`
  Parameters: | service (str) – ID of service to create case for category (str) – If set, assign given category to new case (by category shortname). type (str) – Type of case to create status (str) – Status of case to create. If not set, system will select automatically. watchers (list) – Explicit watchers to add to this case. fields (list) – Fields to set on case creation. Fields in the policy for requested service and customer specifies fields available. If any of the fields in the policy are required on create, and do not have a default value,those fields must be set in the case create request, or the request will fail. subject (str) – Subject of case to create. => [sw{}$-().[]“‘_/,*+#:@!?;]* description (str) – Case description. May use HTML, which will be sanitized. customerReference (str) – Customer reference for case. => [sw{}$-().[]“‘_/,*+#:@!?;]* aclMembers (list) – Explicit ACL members to add to case. originEmailAddress (str) – If case is created from an email, specify origin email address here => format:email publish (bool) – Whether to publish new case. Creating an unpublished case requires special permission. (default true) defaultWatchers (bool) – Whether to enable default watchers for this case. If set to false, default watchers will not be enabled, and will not be notified upon creation of this case. (default true) priority (str) – Priority of case to create. (default medium) accessMode (str) – Access mode for new case. (default roleBased) customerID (int) – ID of customer to create case for (default 0)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 56, “limit”: 795, “responseCode”: 200, “count”: 796, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Add fight yourself add meet hair.”, “messageTemplate”: “Ability edge lawyer successful.”, “field”: “Read able democratic a produce middle.”, “parameter”: {}, “timestamp”: 135403322}], “currentPage”: 535, “size”: 997}

`api.cases.v2.case.` `current_user_watcher_status`(caseID: int, email: bool = 'False', sms: bool = 'False', verbose: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Query and set watcher status for the current user on this case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID email (bool) – If true, enable email notification for current user. If false, disable email. Default is no change. sms (bool) – If true, enable SMS notification for current user. If false, disable SMS. Default is no change. verbose (bool) – If set, explicitly set verbosity for watcher for enabled contact methods (will override default settings on current user)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 109, “limit”: 364, “responseCode”: 200, “count”: 809, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Dark tend go travel.”, “messageTemplate”: “Cultural vote ready anything order make.”, “field”: “Music entire water arm sport matter image project.”, “parameter”: {}, “timestamp”: 224168203}], “currentPage”: 500, “size”: 178}

`api.cases.v2.case.` `delete_attachment`(caseID: int, attachmentID: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete specified attachment from case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID attachmentID (str) – Attachment ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 77, “limit”: 735, “responseCode”: 200, “count”: 443, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Dream matter picture break successful several.”, “messageTemplate”: “Economic degree walk beautiful.”, “field”: “Apply woman yet wind.”, “parameter”: {}, “timestamp”: 1350768235}], “currentPage”: 972, “size”: 804}

`api.cases.v2.case.` `delete_case`(caseID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Mark existing case as deleted (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 937, “limit”: 530, “responseCode”: 200, “count”: 104, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Direction what more when who size street.”, “messageTemplate”: “Visit forget edge must parent fight only TV.”, “field”: “Attention involve visit lead score when gun.”, “parameter”: {}, “timestamp”: 263247423}], “currentPage”: 180, “size”: 946}

`api.cases.v2.case.` `delete_case_link`(caseID: int, linkID: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Remove existing case link (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID linkID (str) – Link ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 371, “limit”: 821, “responseCode”: 200, “count”: 87, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Wear father moment wait house last forward.”, “messageTemplate”: “Identify owner late when bed lead weight success.”, “field”: “Imagine appear pull without recognize guy school maybe.”, “parameter”: {}, “timestamp”: 547782255}], “currentPage”: 3, “size”: 631}

`api.cases.v2.case.` `delete_comment`(caseID: int, commentID: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Mark existing comment as deleted (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID commentID (str) – Comment ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 472, “limit”: 27, “responseCode”: 200, “count”: 616, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Sound point reveal whom run morning.”, “messageTemplate”: “Lot instead marriage see fly moment.”, “field”: “Partner worry successful best seek believe.”, “parameter”: {}, “timestamp”: 1517920261}], “currentPage”: 398, “size”: 442}

`api.cases.v2.case.` `download_attachment`(caseID: int, attachmentID: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Download specific attachment contents. (PUBLIC) Returns data stream with the attachments mimetype, and attachment disposition with filename. Use /cases/v1/case/{caseID}/attachments/{attachmentID} to fetch metadata about this attachment.

  Return type: | `dict`

`api.cases.v2.case.` `edit_comment`(caseID: int, commentID: str, comment: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Edit existing comment (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID commentID (str) – Comment ID comment (str) – Updated comment
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 582, “limit”: 750, “responseCode”: 200, “count”: 282, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Appear response move trouble amount specific.”, “messageTemplate”: “Service decide meet.”, “field”: “Listen fast itself business impact number eight.”, “parameter”: {}, “timestamp”: 1448439659}], “currentPage”: 300, “size”: 608}

`api.cases.v2.case.` `get_attachment`(caseID: int, attachmentID: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch specific attachment metadata (PUBLIC) Use /cases/v1/case/{caseID}/attachments/{attachmentID}/download to download attachment contents.

  Return type: | `dict`

`api.cases.v2.case.` `get_case_comment`(caseID: int, commentID: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch specific comment (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID commentID (str) – Comment ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 971, “limit”: 600, “responseCode”: 200, “count”: 102, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Save establish increase color store of here property.”, “messageTemplate”: “Should tough weight director music plant soldier.”, “field”: “Million ten debate health little.”, “parameter”: {}, “timestamp”: 1228861801}], “currentPage”: 367, “size”: 909}

`api.cases.v2.case.` `get_case_metadata_by_id`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns the basic case descriptor for the case identified by ID (PUBLIC)

  Return type: | `dict`
  Parameters: | id (int) – Case ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 996, “limit”: 515, “responseCode”: 200, “count”: 700, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Quickly series sport set might message.”, “messageTemplate”: “National reason discover treatment degree time field.”, “field”: “Reach song rest spend significant action.”, “parameter”: {}, “timestamp”: 1136003030}], “currentPage”: 556, “size”: 548}

`api.cases.v2.case.` `grant_access`(caseID: int, subjectID: int = None, level: str = 'read', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Grant access to a case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID subjectID (int) – ID of subject (user or group) to grant access to. level (str) – Level to grant for subject. (default read)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 328, “limit”: 921, “responseCode”: 200, “count”: 881, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Maybe peace social traditional short.”, “messageTemplate”: “Body decide lose never school.”, “field”: “Body brother skill remain serious experience when.”, “parameter”: {}, “timestamp”: 1506828304}], “currentPage”: 957, “size”: 797}

`api.cases.v2.case.` `list_case_a_c_l`(caseID: int, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List ACL entries for an existing case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID offset (int) – Skip a number of results limit (int) – Maximum number of returned results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 82, “limit”: 459, “responseCode”: 200, “count”: 480, “data”: [{“id”: “Difficult civil particular science seat pretty fear.”, “addedTimestamp”: 221034567, “addedByUser”: {“id”: 566, “customerID”: 744, “userName”: “pattersonkelly”, “name”: “Charles Benson”}, “grantedSubject”: {“id”: 62, “customerID”: 340, “name”: “Charles Chen”}, “flags”: [“DELETED”], “level”: “read”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Car sing knowledge test interview others station.”, “messageTemplate”: “Deal ask home.”, “field”: “There several there chance social.”, “parameter”: {}, “timestamp”: 609090771}], “currentPage”: 754, “size”: 390}

`api.cases.v2.case.` `list_case_attachments`(caseID: int, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List attachments for an existing case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID offset (int) – Skip a number of results limit (int) – Maximum number of returned results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 676, “limit”: 653, “responseCode”: 200, “count”: 911, “data”: [{“id”: “You TV necessary effect.”, “addedTimestamp”: 701250330, “addedByUser”: {“id”: 417, “customerID”: 864, “userName”: “jakezimmerman”, “name”: “Marcus Shepherd”}, “name”: “Timothy Williams”, “mimeType”: “Game thing money cup base vote defense.”, “flags”: [“DELETED”], “size”: 91}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Instead training clear enter generation today past.”, “messageTemplate”: “Evidence box strong pay despite.”, “field”: “Finally serve bed ready in again.”, “parameter”: {}, “timestamp”: 1164603366}], “currentPage”: 416, “size”: 323}

`api.cases.v2.case.` `list_case_comments`(caseID: int, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List comments for an existing case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID offset (int) – Skip a number of results limit (int) – Maximum number of returned results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 187, “limit”: 983, “responseCode”: 200, “count”: 402, “data”: [{“id”: “Can official scientist fight defense risk often room.”, “addedTimestamp”: 1032963722, “addedByUser”: {“id”: 184, “customerID”: 801, “userName”: “donna59”, “name”: “Maria Cook”}, “comment”: “Pattern woman difference since.”, “reference”: “Factor century public instead room people system.”, “flags”: [“REPLACED”], “status”: “pendingClose”, “priority”: “medium”, “properties”: {“additionalProperties”: “Would low onto matter owner ever source international.”}}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Born allow skin economic manage describe.”, “messageTemplate”: “Break foreign simply provide rise speak brother.”, “field”: “Realize season win fear lot piece.”, “parameter”: {}, “timestamp”: 280884774}], “currentPage”: 983, “size”: 874}

`api.cases.v2.case.` `list_case_links`(caseID: int, direction: str = None, type: list = None, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List links for an existing case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID direction (str) – Specify direction of links to fetch (default all) type (list) – Specify link types to fetch (default all) offset (int) – Skip a number of results limit (int) – Maximum number of returned results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 711, “limit”: 618, “responseCode”: 200, “count”: 10, “data”: [{“id”: “Although he exist stock.”, “addedTimestamp”: 283079329, “addedByUser”: {“id”: 66, “customerID”: 694, “userName”: “james25”, “name”: “Christopher Smith”}, “flags”: [“DELETED”], “direction”: “incoming”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Discover new own safe cost citizen fast might.”, “messageTemplate”: “Or company someone quality.”, “field”: “Kid morning face outside general late drug.”, “parameter”: {}, “timestamp”: 1283607209}], “currentPage”: 976, “size”: 211}

`api.cases.v2.case.` `list_case_tags`(caseID: int, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List tags for an existing case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID offset (int) – Skip a number of results limit (int) – Maximum number of returned results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 77, “limit”: 572, “responseCode”: 200, “count”: 964, “data”: [{“id”: “Remain like bad seven article.”, “addedTimestamp”: 1448893893, “addedByUser”: {“id”: 811, “customerID”: 212, “userName”: “bchase”, “name”: “Maria Hernandez”}, “key”: “She baby as act however improve focus.”, “value”: “Paper chair short order listen wonder idea.”, “flags”: [“DELETED”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Must kind bank court keep same pay.”, “messageTemplate”: “Energy military reality often.”, “field”: “Themselves remain until size.”, “parameter”: {}, “timestamp”: 987366529}], “currentPage”: 483, “size”: 795}

`api.cases.v2.case.` `list_case_watchers`(caseID: int, offset: int = 0, limit: int = 25, includeExplicit: bool = 'True', includeDefault: bool = 'True', includeDisabled: bool = 'True', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List watchers for an existing case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID offset (int) – Skip a number of results limit (int) – Maximum number of returned results includeExplicit (bool) – Include explicit watchers (default true) includeDefault (bool) – Include default watchers (default true) includeDisabled (bool) – Include disabled watchers (default false)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 43, “limit”: 151, “responseCode”: 200, “count”: 198, “data”: [{“id”: “Report likely how want throw white.”, “addedTimestamp”: 579038850, “addedByUser”: {“id”: 416, “customerID”: 992, “userName”: “williamjones”, “name”: “Brian Cervantes”}, “flags”: [“VERBOSE”], “subject”: {“id”: 475, “customerID”: 299, “name”: “Deanna Turner”}, “contactID”: 640, “role”: “watcher”, “destination”: “Attention high image.”, “minimumPriority”: “high”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Song guy middle later customer.”, “messageTemplate”: “Establish with improve reality town executive.”, “field”: “Like impact machine me determine training up family.”, “parameter”: {}, “timestamp”: 827772804}], “currentPage”: 592, “size”: 855}

`api.cases.v2.case.` `list_workflows`(caseID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List workflows for an existing case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 740, “limit”: 999, “responseCode”: 200, “count”: 456, “data”: [{“id”: “Machine life participant ago risk.”, “addedTimestamp”: 399763677, “addedByUser”: {“id”: 543, “customerID”: 659, “userName”: “weberandrew”, “name”: “Jamie Odom”}, “workflow”: “validation”, “acknowledgedByUser”: {“id”: 19, “customerID”: 213, “userName”: “patrick96”, “name”: “Lisa Martin”}, “acknowledgedTimestamp”: 931296804, “flags”: [“DELETED”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Receive food political remain better the shoulder.”, “messageTemplate”: “Onto certainly or degree character.”, “field”: “Boy ground third kitchen entire.”, “parameter”: {}, “timestamp”: 558798475}], “currentPage”: 639, “size”: 122}

`api.cases.v2.case.` `merge_cases`(mergeInto: int, mergeFrom: int, description: str = None, priority: str = None, status: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Merge two cases (PUBLIC) This will merge the contents of the mergeFrom case into the mergeInto case.The mergeFrom case will be marked as deleted/merged, and the mergeInto case will continue to exist, but with entries and attachments from the mergeFrom case embedded into it.If nothing else is specified, the status and priority of the mergeInto case will be retained.

  Return type: | `dict`

`api.cases.v2.case.` `move_case`(id: int, customerID: int = None, service: str = None, category: str = None, type: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Move a case to a differnet category, service or customer (PUBLIC)

  Return type: | `dict`
  Parameters: | id (int) – Case ID customerID (int) – If set, move case to specified customer. service (str) – If set, move case to specified service. category (str) – If set, assign given category to specified category (by category shortname). Set value to empty string to unset category. type (str) – If set, move case to specified type.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 258, “limit”: 78, “responseCode”: 200, “count”: 503, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Value direction investment relate.”, “messageTemplate”: “Add class east follow edge add garden simply.”, “field”: “Carry card toward relate.”, “parameter”: {}, “timestamp”: 1095313103}], “currentPage”: 18, “size”: 423}

`api.cases.v2.case.` `publish_case`(caseID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Publish existing case not marked as published (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 378, “limit”: 698, “responseCode”: 200, “count”: 711, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Daughter center west table offer former.”, “messageTemplate”: “Toward along only where sound.”, “field”: “Here property maybe.”, “parameter”: {}, “timestamp”: 1363435714}], “currentPage”: 349, “size”: 510}

`api.cases.v2.case.` `remove_access`(caseID: int, aclEntryID: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Revoke access from a case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID aclEntryID (str) – ACL entry to revoke
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 814, “limit”: 977, “responseCode”: 200, “count”: 864, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Themselves try mind.”, “messageTemplate”: “Trip last someone be cell.”, “field”: “Art next cold feeling.”, “parameter”: {}, “timestamp”: 858566420}], “currentPage”: 811, “size”: 905}

`api.cases.v2.case.` `remove_case_contact_watcher`(caseID: int, contactID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Remove a specific contact listed in the default watchers from watching this case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID contactID (int) – Contact ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 933, “limit”: 230, “responseCode”: 200, “count”: 253, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Short two drive gas personal property just.”, “messageTemplate”: “Material section boy people either.”, “field”: “Thing remain brother center.”, “parameter”: {}, “timestamp”: 1112087172}], “currentPage”: 597, “size”: 970}

`api.cases.v2.case.` `remove_case_tag_by_id`(caseID: int, tagID: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Remove existing tag (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID tagID (str) – Tag ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 108, “limit”: 840, “responseCode”: 200, “count”: 434, “data”: [{“id”: “Meet order news management follow camera.”, “addedTimestamp”: 156404593, “addedByUser”: {“id”: 699, “customerID”: 283, “userName”: “melissadixon”, “name”: “Benjamin Cox”}, “key”: “Few myself can music anyone difficult.”, “value”: “Call similar break help.”, “flags”: [“DELETED”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Second walk for race world themselves cup.”, “messageTemplate”: “Television all yet training.”, “field”: “Manage scene talk form science anyone question head.”, “parameter”: {}, “timestamp”: 391366044}], “currentPage”: 624, “size”: 165}

`api.cases.v2.case.` `remove_case_tag_by_key_value`(caseID: int, tagKey: str, tagValue: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Remove existing tag (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID tagKey (str) – Tag Key tagValue (str) – Tag Value
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 655, “limit”: 278, “responseCode”: 200, “count”: 341, “data”: [{“id”: “Authority road produce forget accept plant none.”, “addedTimestamp”: 764305400, “addedByUser”: {“id”: 186, “customerID”: 247, “userName”: “maryjordan”, “name”: “Darrell Moore”}, “key”: “Picture consumer scene.”, “value”: “Lose west view evidence add.”, “flags”: [“DELETED”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Training ahead beat age.”, “messageTemplate”: “System action toward clear deep none same.”, “field”: “Need similar place attack work address loss.”, “parameter”: {}, “timestamp”: 287362782}], “currentPage”: 592, “size”: 897}

`api.cases.v2.case.` `remove_case_watcher`(caseID: int, watcherID: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Remove specific watcher from a case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID watcherID (str) – Watcher ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 342, “limit”: 586, “responseCode”: 200, “count”: 618, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Water air eight.”, “messageTemplate”: “Population if each speak.”, “field”: “Gun director break than out.”, “parameter”: {}, “timestamp”: 719029012}], “currentPage”: 548, “size”: 529}

`api.cases.v2.case.` `remove_current_user_watcher`(caseID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Remove the current user from the watchlist of this case.If the currentuser is a contact, this will override the contact settings for the current user for this case. (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 313, “limit”: 521, “responseCode”: 200, “count”: 881, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Season order doctor.”, “messageTemplate”: “Certain himself staff type authority south.”, “field”: “Mention purpose choice any establish similar.”, “parameter”: {}, “timestamp”: 408510158}], “currentPage”: 142, “size”: 486}

`api.cases.v2.case.` `request_workflow`(caseID: int, workflow: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Request new workflow on case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID workflow (str) – Workflow to request
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 644, “limit”: 197, “responseCode”: 200, “count”: 170, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Provide although decision also citizen worry present building.”, “messageTemplate”: “Behavior activity whom sit hand truth do.”, “field”: “With hard find local.”, “parameter”: {}, “timestamp”: 95566046}], “currentPage”: 708, “size”: 775}

`api.cases.v2.case.` `search_case_statistics`(limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, caseID: list = None, type: list = None, service: list = None, category: list = None, status: list = None, priority: list = None, startTimestamp: int = None, endTimestamp: int = None, assetID: list = None, tag: list = None, workflow: list = None, field: list = None, keywords: list = None, timeFieldStrategy: list = None, timeMatchStrategy: str = None, keywordFieldStrategy: list = None, keywordMatchStrategy: str = None, userID: list = None, userFieldStrategy: list = None, groupBy: list = None, values: list = None, resolution: int = None, cutoff: int = None, cutoffValue: str = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', userAssigned: bool = 'False', techAssigned: bool = 'False', includeOthers: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns statistics data matching the defined CaseStatsSearchCriteria (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. caseID (list) – Restrict search to specific cases (by ID). type (list) – Restrict search to entries of one of these types. service (list) – Restrict search to entries of one of these services (by service shortname or ID). category (list) – Restrict search to entries of one of these categories (by category shortname or ID). status (list) – Restrict search to entries of one of these statuses. priority (list) – Restrict search to entries with given priorties startTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (start timestamp). endTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (end timestamp). assetID (list) – Restrict search to cases associated with specified assets (hosts, services or processes) tag (list) – Restrict search to entries matching the given tag criteria. workflow (list) – Restrict search to entries matching the given workflow criteria. field (list) – Restrict search to entries matching the given field criteria. keywords (list) – Search for keywords. timeFieldStrategy (list) – Defines which timestamps will be included in the search (default lastUpdatedTimestamp). timeMatchStrategy (str) – Defines how strict to match against different timestamps (all/any) using start and end timestamp (default any) keywordFieldStrategy (list) – Defines which fields will be searched by keywords (default all supported fields). keywordMatchStrategy (str) – Defines the MatchStrategy for keywords (default match all keywords). userID (list) – Restrict search to cases associated with these users. userFieldStrategy (list) – Defines which user fields will be searched (default match all user fields). groupBy (list) – Specify which fields will be grouped by in stats values (list) – Specify which values will be included in stats (default created) resolution (int) – Stats resolution period in milliseconds, if is 0 means to generate non-timeline statistics cutoff (int) – Reduce stats keys to the cutoff amount of keys that has largest hit count, default 0 means no reduce cutoffValue (str) – Specify which value to be cutoff on (default created) sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). userAssigned (bool) – If set, limit search to cases where assignedUser field is set/unset techAssigned (bool) – If set, limit search to cases where assignedTech field is set/unset includeOthers (bool) – If reduce (cutoff>0), true means remaining keys (other than cutoff keys) are collected into an “other” key, default false
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 414, “limit”: 319, “responseCode”: 200, “count”: 417, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Lead seat he recent.”, “messageTemplate”: “Care mother by that last nation.”, “field”: “Protect reveal record or our parent possible.”, “parameter”: {}, “timestamp”: 116773974}], “currentPage”: 900, “size”: 556}

`api.cases.v2.case.` `simple_case_search`(customerID: list = None, service: list = None, status: list = None, type: list = None, keywords: list = None, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns cases matching the query parameters (PUBLIC)

  Return type: | `dict`
  Parameters: | customerID (list) – Limit result to specified customers service (list) – Limit result to specified services (service shortname) status (list) – Limit result to specified statuses type (list) – Limit result to specified types keywords (list) – Search by keywords offset (int) – Skip a number of results limit (int) – Maximum number of returned results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 502, “limit”: 209, “responseCode”: 200, “count”: 866, “data”: [{“id”: 827, “initialStatus”: “pendingCustomer”, “status”: “pendingCustomer”, “initialPriority”: “high”, “priority”: “high”, “subject”: “Someone traditional letter join blue lay.”, “description”: “Top idea size.”, “customerReference”: “During possible owner million doctor hand employee.”, “accessMode”: “explicit”, “reporter”: {“id”: 563, “customerID”: 531, “userName”: “rcook”, “name”: “Latasha Davis”}, “assignedUser”: {“id”: 157, “customerID”: 292, “userName”: “tim91”, “name”: “Kelsey Taylor”}, “assignedTech”: {“id”: 340, “customerID”: 211, “userName”: “bmullins”, “name”: “Timothy Gates”}, “createdTimestamp”: 727653242, “createdByUser”: {“id”: 454, “customerID”: 984, “userName”: “xmoore”, “name”: “Kevin Stanley”}, “lastUpdatedTimestamp”: 814589572, “lastUpdatedByUser”: {“id”: 612, “customerID”: 441, “userName”: “donpeterson”, “name”: “Susan Rojas”}, “closedTimestamp”: 145387643, “closedByUser”: {“id”: 127, “customerID”: 684, “userName”: “willie14”, “name”: “Melissa Carlson”}, “publishedTimestamp”: 772394412, “publishedByUser”: {“id”: 41, “customerID”: 569, “userName”: “robertsoncharles”, “name”: “Donna Campbell”}, “flags”: [“DEFAULT_CONTACTS”], “properties”: {“additionalProperties”: “Husband under theory buy trial into.”}}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Capital foot account shoulder pay.”, “messageTemplate”: “Message police man compare.”, “field”: “Report fly great like play few.”, “parameter”: {}, “timestamp”: 824519623}], “currentPage”: 739, “size”: 459}

`api.cases.v2.case.` `update_case`(id: int, subject: str = None, description: str = None, status: str = None, priority: str = None, category: str = None, reporterID: int = None, assignedUserID: int = None, assignedTechID: int = None, customerReference: str = None, comment: str = None, originEmailAddress: str = None, internalComment: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Request changes to basic fields of an existing case (PUBLIC)

  Return type: | `dict`
  Parameters: | id (int) – Case ID subject (str) – If set, change subject of case. => [sw{}$-().[]“‘_/,*+#:@!?;]* description (str) – If set, change description of case. May use HTML, will be sanitized. status (str) – If set, change status of case priority (str) – If set, change priority of case. category (str) – If set, assign given category to specified category (by category shortname). Set value to empty string to unset category. reporterID (int) – If set, set given user as reporter for case. assignedUserID (int) – If set, assign given user to case. assignedTechID (int) – If set, assign given technical user (solution engineer) to case. customerReference (str) – If set, change customer reference for case. => [sw{}$-().[]“‘_/,*+#:@!?;]* comment (str) – If set, add comment to case. May use HTML, will be sanitized. originEmailAddress (str) – If update is made from an email, specify origin email address here => format:email internalComment (bool) – If true, add comment as internal.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 807, “limit”: 265, “responseCode”: 200, “count”: 349, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Recent at wear positive in live.”, “messageTemplate”: “Born car together experience follow factor throughout.”, “field”: “More perhaps investment face amount factor.”, “parameter”: {}, “timestamp”: 812494690}], “currentPage”: 65, “size”: 507}

`api.cases.v2.case.` `update_case_watcher`(caseID: int, watcherID: str, verbose: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Update settings for a specific watcher on a case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID watcherID (str) – Watcher ID verbose (bool) – If set, will enable/disable verbose status for this watcher.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 563, “limit”: 755, “responseCode”: 200, “count”: 685, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Score coach science eight that top.”, “messageTemplate”: “Value work from ask determine thing ability.”, “field”: “Resource affect suddenly leg number.”, “parameter”: {}, “timestamp”: 666276656}], “currentPage”: 748, “size”: 635}

`api.cases.v2.case.` `update_watcher_settings`(caseID: int, defaultWatchers: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Update general watcher settings on a case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID defaultWatchers (bool) – If set, will enable/disable use of default watchers on this case.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 2, “limit”: 554, “responseCode”: 200, “count”: 155, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Perform stock surface discussion.”, “messageTemplate”: “Child show executive catch most phone.”, “field”: “Control research view stay.”, “parameter”: {}, “timestamp”: 42443497}], “currentPage”: 930, “size”: 875}

## api.cases.v2.category module

Autogenerated API

## api.cases.v2.service module

Autogenerated API

## api.cases.v2.servicesubscription module

Autogenerated API

## Module contents